package schedframe.resources.computing.profiles.energy.power.ui;



import schedframe.resources.ResourceStatus;
import schedframe.resources.computing.ComputingResource;
import schedframe.resources.computing.Node;
import schedframe.resources.computing.profiles.energy.EnergyEvent;
import schedframe.resources.computing.profiles.energy.EnergyEventType;
import schedframe.resources.computing.profiles.energy.power.PowerProfile;
import schedframe.resources.computing.profiles.energy.power.PowerStateName;
import schedframe.resources.computing.profiles.energy.power.StandardPowerStateName;

public class NodePowerInterface extends ComputingResourcePowerInterface{

	public NodePowerInterface(ComputingResource resource, PowerProfile pp){
		super(resource, pp);
		currentPowerState = StandardPowerStateName.ON;
	}

	public boolean setPowerState(PowerStateName state){
		if(!supportPowerState(state))
			return false;
		if(state != currentPowerState){
			currentPowerState = state;
			
			Node node = (Node) resource;
			for(ComputingResource child:node.getProcessors()){
				if(child.getPowerInterface() != null){
					child.getPowerInterface().setPowerState(state);	
				}
			}

			if(state == StandardPowerStateName.OFF){
				node.setStatus(ResourceStatus.UNAVAILABLE);
			}
			else if(state == StandardPowerStateName.ON){
				node.setStatus(ResourceStatus.FREE);
			}
	
			node.handleEvent(new EnergyEvent(EnergyEventType.POWER_STATE_CHANGED, node.getFullName()));

			//node.handleEvent(new EnergyEvent(EnergyEventType.POWER_STATE_CHANGED, computingNode.getName()));
			//ResourceController.traceResource(new DateTime().getMillis(), resource.getFullName(), "POWER_STATE_CHANGED", state.getName());	
		}
		return true;
	}

	public void turnOn(){
		setPowerState(StandardPowerStateName.ON);
	}
	
	public void turnOff(){
		setPowerState(StandardPowerStateName.OFF);
	}



}